Learn R Programming

eiExpand (version 1.0.5)

south_carolina: Example election and demographic data from South Carolina 2020 General Elections

Description

Example election and demographic data from South Carolina 2020 General Elections

Usage

south_carolina

Arguments

Format

An object of class data.frame with 750 rows and 42 columns.